# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.12](https://github.com/bnkc/emval/compare/v0.1.11...v0.1.12) - 2025-11-09

### Other

- Normalize IDN to Unicode rather than ASCII
- Normalize local-part to NFKC
- Remove redundant check for non-UTF-8 characters
- quick push

## [0.1.11](https://github.com/bnkc/emval/compare/v0.1.10...v0.1.11) - 2025-10-28

### Fixed

- resolve merge conflicts

### Other

- regenerate by maturin and add env: `CFLAGS_s390x_unknown_linux_gnu: -march=z10`
- added `allowed_special_domains` for `EmailValidator` and `validate_email`

## [0.1.10](https://github.com/bnkc/emval/compare/v0.1.9...v0.1.10) - 2025-09-14

### Other

- use stable rust compiler

## [0.1.9](https://github.com/bnkc/emval/compare/v0.1.7...v0.1.9) - 2025-06-26

### Fixed

- Fixed pip installation error caused by LICENSE file path conflict in wheel packaging

## [0.1.7](https://github.com/bnkc/emval/compare/v0.1.6...v0.1.7) - 2025-06-26

### Other

- release v0.1.6

## [0.1.6](https://github.com/bnkc/emval/compare/v0.1.5...v0.1.6) - 2025-06-26

### Other

- quick push
- Some cleanups
- Update README
- Update pyo3 signature
- Add allowed_special_domains configuration option
- Update README.md
- Update README.md

## [0.1.5](https://github.com/bnkc/emval/compare/v0.1.4...v0.1.5) - 2024-12-05

### Other

- updating workflow files

### Changed

- Merge pull request #4 from bnkc/dependabot/cargo/pyo3-0.22.4
- Bump pyo3 from 0.22.2 to 0.22.4
- Changing toolchain
- Completed domain deliverability
- Restructuring project
- Update README.md

## [1.0.0] - 2024-08-08

### Added

- Add files via upload

### Changed

- Updating toml
- Renaming to emval
- Update README.md
- Update README.md
- Update benchmark.py
- Delete benchmark_results.svg
- Delete test.py
- Update README.md
- Delete perf.png
- Began new benchmarking
- Flattened out ValidatedEmail, working on valid tests
- Update README.md
- Update README.md
- Update README.md
- Create LICENSE
- Update README.md
- Update README.md
- Starting readme
- Close to completeing invalid syntax testing
- Deliverable flag and more invalid email tests
- Better PyError handling
- Python bindings
- Preparing for python binding migration
- Refactored tests, added original and normalized email to struct
- Validate special domains
- Setup case testing, passing test suite
- Still working on quoted local part tests
- Quoted local part tests pass
- Domain literals completed
- Working on fixing domain testing and validation
- Benchmarking
- Initial commit for new project structure

[unreleased]: https://github.com/bnkc/emval/compare/v1.0.0..HEAD

<!-- generated by git-cliff -->
